/*
 * Copyright (c) 2010 Ingres Corp.
 */

#include <time.h>
#include <stdio.h>
#include <stdlib.h>
#include <signal.h>
#include <string.h>
#include <sys/types.h>
#include <unistd.h>
#include <sys/stat.h>
#include <fcntl.h>

// borrow RANDOM64 function from TPC-H code
#include "dss.h"
#include "rng64.h"

seed_t Seed[1];

exec sql include sqlca;

#define MAX_DELTA 100
#define DEFAULT_N 10

static void usage(char *msg)
{
	if (msg)
            fprintf(stderr, "%s\n", msg);
	fprintf( stderr, "usage: acidkeys -b <dbms> [-c <N>]\n");
	fprintf( stderr, "\tprint N O_KEY L_KEY delta tripples to stdout\n");
    fprintf( stderr, "\tN defaults to %d\n",DEFAULT_N);
	exit(0);
}

int main( int argc, char **argv)
{
	exec sql begin declare section;
		char *database=NULL;
        long long max_orderkey;
        int max_m;
        long long rand_o_key;
        short ind;
	exec sql end declare section;

	DSS_HUGE rand_l_key;
    DSS_HUGE rand_delta;
    int count=DEFAULT_N;
    char c;
	extern char *optarg;
    extern int optind, optopt;

	long rndm = (long)((unsigned)time(NULL) * getpid()); // seed to the RNG

	Seed[0].value = rndm;
	//printf("-- using %ld as a seed to the RNG\n", rndm);

	while ((c = getopt(argc, argv, ":b:c:")) != -1)
		switch (c) {
		case 'b':
			database = optarg;
			break;
		case 'c':
			count = atol(optarg);
			break;
		case ':':  /* -b or -c without arguments */
			usage("option requires an argument");
			break;
		case '?':
			usage("unknown option");
	}

	if (database == NULL)
		usage("no database specified");

	exec sql whenever sqlerror stop;
	exec sql connect to :database;
    exec sql select max(l_orderkey) into :max_orderkey from lineitem;

    while (count--) {
    	ind = -1;
        while (ind == -1) {
        	RANDOM64(rand_o_key, 1, max_orderkey, 0);
            exec sql select max(l_linenumber) into :max_m:ind from lineitem
                     where l_orderkey = :rand_o_key;
        }

        RANDOM64(rand_l_key, 1, max_m, 0);
        RANDOM64(rand_delta, 1, 100, 0);
        printf("%lld %lld %lld\n",rand_o_key, rand_l_key, rand_delta);
    }

    return(0);
}
