#!/bin/bash

#
# Copyright (c) 2010 Ingres Corp.
#

TOPDIR="`cat .topdir`"       
IVWDIR="$TOPDIR/scripts/ingres_vectorwise"

usage()
{
cat << EOF
usage: $0 -d <db>

The script runs TPC-H ACID Isolation Test #4b

OPTIONS:
    -h              show this message
    -d  <database>  database name
EOF
}

DATABASE=
while getopts "d:" opt; do
    case $opt in
        d)
            DATABASE=$OPTARG
            ;;
        ?)
            usage
            exit 1
            ;;
    esac
done

if [ -z "$DATABASE" ]; then
	usage
	exit 1
fi

echo "==============================================================="
echo "TPC-H Isolation Test #4b started at `date`"
echo "==============================================================="
echo

# truncate HISTORY table
echo "Truncate the HISTORY table:"
echo "delete from HISTORY;\p\g" | sql $DATABASE

# create directory to store test-related data
#
OUTPUT_DIR="$IVWDIR/acid/iso/output"
mkdir -p $OUTPUT_DIR

# generate random values 
#
RAND_VALUES=`$IVWDIR/acid/acidkeys -b $DATABASE -c 1`
RAND_O_KEY=`echo $RAND_VALUES | awk '{printf $1}'`
RAND_L_KEY=`echo $RAND_VALUES | awk '{printf $2}'`
RAND_DELTA1=`echo $RAND_VALUES | awk '{printf $3}'`

# generate a 2nd random delta
#
AUX=`$IVWDIR/acid/acidkeys -b $DATABASE -c 1`
RAND_DELTA2=`echo $AUX | awk '{printf $3}'`
RAND_VALUES2="$RAND_O_KEY $RAND_L_KEY $RAND_DELTA2"

echo "Random values used:"
echo "O_KEY  = $RAND_O_KEY"
echo "L_KEY  = $RAND_L_KEY"
echo "DELTA1 = $RAND_DELTA1"
echo "DELTA2 = $RAND_DELTA2"

# Start ACID query (Txn1)
#
$IVWDIR/acid/acidquery.sh -d $DATABASE -o $RAND_O_KEY | tee $OUTPUT_DIR/output_iso4b_Txn1

# Start an ACID txn and suspend for 40 seconds prior to ROLLBACK
# using RAND_O_KEY, RAND_L_KEY and RAND_DELTA1
#
echo $RAND_VALUES | $IVWDIR/acid/acidtrans_rb -b $DATABASE -s 40 | tee $OUTPUT_DIR/output_iso4b_Txn2 2>&1 &

# Sleep 10 seconds before starting the ACID query
#
sleep 10

# Start another ACID transaction to ROLLBACK
# using RAND_O_KEY, RAND_L_KEY and RAND_DELTA2 
#
echo $RAND_VALUES2 | $IVWDIR/acid/acidtrans_rb -b $DATABASE -s 0 | tee $OUTPUT_DIR/output_iso4b_Txn3 2>&1 &

wait

# Start ACID query (Txn4)
#
$IVWDIR/acid/acidquery.sh -d $DATABASE -o $RAND_O_KEY | tee $OUTPUT_DIR/output_iso4b_Txn4

# show HISTORY table
echo
echo "Contents of the HISTORY table:"
echo "select * from HISTORY;\p\g" | sql $DATABASE

echo
echo Verify files:
echo $OUTPUT_DIR/output_iso4b_Txn1
echo $OUTPUT_DIR/output_iso4b_Txn2

echo
echo "TPC-H Isolation Test #4b ended at `date`"
echo
