#!/bin/bash

#
# Copyright (c) 2010 Ingres Corp.
#

TOPDIR="`cat .topdir`"        
IVWDIR="$TOPDIR/scripts/ingres_vectorwise"

usage()
{
cat << EOF
usage: $0 -d <db>

The script runs TPC-H ACID Isolation Test #6

OPTIONS:
    -h              show this message
    -d  <database>  database name
EOF
}

DATABASE=
while getopts "d:" opt; do
    case $opt in
        d)
            DATABASE=$OPTARG
            ;;
        ?)
            usage
            exit 1
            ;;
    esac
done

if [ -z "$DATABASE" ]; then
	usage
	exit 1
fi

echo "==============================================================="
echo "TPC-H Isolation Test #6 started at `date`"
echo "==============================================================="
echo

# truncate HISTORY table
echo "Truncate the HISTORY table:"
echo "delete from HISTORY;\p\g" | sql $DATABASE

# create directory to store test-related data
#
OUTPUT_DIR="$IVWDIR/acid/iso/output"
mkdir -p $OUTPUT_DIR

# generate random values for Txn2
#
RAND_VALUES=`$IVWDIR/acid/acidkeys -b $DATABASE -c 1`
RAND_O_KEY=`echo $RAND_VALUES | awk '{printf $1}'`
RAND_L_KEY=`echo $RAND_VALUES | awk '{printf $2}'`
RAND_DELTA=`echo $RAND_VALUES | awk '{printf $3}'`

echo "Random values used:"
echo "O_KEY  = $RAND_O_KEY"
echo "L_KEY  = $RAND_L_KEY"
echo "DELTA  = $RAND_DELTA"
echo

do_q1()
{
    # Start Txn1
    # do 10 sequential Query 1s with DELTA=0..9
    for ((s=0;s<10; s++)); do
        $IVWDIR/acid/iso/iso6_txn.sh -d $DATABASE -s $s
    done
}
do_q1 | tee $OUTPUT_DIR/output_iso6_Txn1 2>&1 & 

# Start Txn2
#
echo $RAND_VALUES | $IVWDIR/acid/acidtrans -b $DATABASE | tee $OUTPUT_DIR/output_iso6_Txn2 2>&1 &

# wait for transactions to complete
#
wait

# show HISTORY table
echo
echo "Contents of the HISTORY table:"
echo "select * from HISTORY;\p\g" | sql $DATABASE

# output files 
echo
echo Verify files:
echo $OUTPUT_DIR/output_iso6_Txn1
echo $OUTPUT_DIR/output_iso6_Txn2

echo
echo "TPC-H Isolation Test #6 ended at `date`"
echo

