/*
 * Copyright (c) 2010 Ingres Corp.
 */

#include <time.h>
#include <stdio.h>
#include <stdlib.h>
#include <signal.h>
#include <string.h>
#include <sys/types.h>
#include <unistd.h>
#include <sys/stat.h>
#include <fcntl.h>

// borrow RANDOM64 function from TPC-H code
#include "dss.h"
#include "rng64.h"

seed_t Seed[1];

EXEC SQL INCLUDE SQLCA;

// Min PS_PARTKEY for the qualification database (SF=1)
#define MIN_PS_PARTKEY 1
// Max PS_PARTKEY for the qualification database (SF=1)
#define MAX_PS_PARTKEY_SF1 200000
// Max PS_PARTKEY for the SF100 database
#define MAX_PS_PARTKEY_SF100 20000000

/*
 * Usage
 */
static void usage(char *msg)
{
	if (msg)
            fprintf(stderr, "%s\n", msg);
	fprintf( stderr, "usage: pskeys -b <dbms> -f <database scale factor>\n");
	exit(0);
}

/*
 * MAIN
 */
int main(int argc, char **argv)
{
	EXEC SQL BEGIN DECLARE SECTION;
		char *database=NULL;
        long long rand_ps_partkey;
        long long rand_ps_suppkey;
	EXEC SQL END DECLARE SECTION;

    char c;
    int scale_factor = 0;
	extern char *optarg;
    extern int optind, optopt;

	long rndm = (long)((unsigned)time(NULL) * getpid()); // RNG seed
	Seed[0].value = rndm;

	while ((c = getopt(argc, argv, ":b:f:")) != -1)
		switch (c) {
		case 'b':
			database = optarg;
			break;
        case 'f':
            scale_factor = atoi(optarg);
            break;
		case ':':  /* -b without arguments */
			usage("option requires an argument");
			break;
		case '?':
			usage("unknown option");
	}

	if (database == NULL)
		usage("no database specified");

    if (scale_factor == 0)
        usage("no scale factor specified");
        
    // generate random number for PS_PARTKEY
    if (scale_factor == 1)
        RANDOM64(rand_ps_partkey, MIN_PS_PARTKEY, MAX_PS_PARTKEY_SF1, 0);
    else if (scale_factor == 100)
        RANDOM64(rand_ps_partkey, MIN_PS_PARTKEY, MAX_PS_PARTKEY_SF100, 0);
    else
        usage("scale factor must be equal to 1 or 100");

	EXEC SQL WHENEVER SQLERROR STOP;
	EXEC SQL CONNECT TO :database;

	EXEC SQL SELECT FIRST 1 PS_SUPPKEY INTO :rand_ps_suppkey
	FROM PARTSUPP WHERE PS_PARTKEY = :rand_ps_partkey;

	printf("%lld %lld\n", rand_ps_partkey, rand_ps_suppkey);

	return(0);
}
