#!/bin/bash

#
# Copyright (c) 2010 Ingres Corp.
#

TOPDIR="`cat .topdir`"        
IVWDIR="$TOPDIR/scripts/ingres_vectorwise"
source $TOPDIR/scripts/kit_profile || er "$0: could not source kit_profile"

while getopts "d:o:q:s:" opt; do
    case $opt in
        d)
            DATABASE=$OPTARG
            ;;
        o)
            OUTPUT_DIR=$OPTARG
            ;;
        q)
            QUERIES_DIR=$OPTARG
            ;;
        s)
            STREAM=$OPTARG
            ;;
        ?)
            echo "Usage: $0"
            echo "     -d  <database> (required)"
            echo "     -s  <stream> (required)"
            echo "     -o  <output directory> (required)"
            echo "     -q  <queries directory> (required)"
            exit 1
    esac
done

mkdir -p ${OUTPUT_DIR}/results/stream${STREAM}

for ((i=1;i<=22;i++)); do
    # Get start time
    s_time=`$GTIME`

    # Get query number
    QUERY=`cat ${QUERIES_DIR}/stream${STREAM}/${i}_*.sql | grep "Query (Q" |  sed -e 's/.*Query (Q\(.*\)/\1/' -e 's/)$//'`
    
    echo "Stream $STREAM - Query ${QUERY}"

	# Execute query
    echo "\nocontinue \p\g `cat ${QUERIES_DIR}/stream${STREAM}/${i}_q${QUERY}.sql` \p\g" | sql -c1 -i420 -t1 ${DATABASE} \
       > ${OUTPUT_DIR}/results/stream${STREAM}/q${QUERY}.output
       
 	if [ "$?" != 0 ]; then       
		echo "Query $QUERY failed. See ${OUTPUT_DIR}/results/stream${STREAM}/q${QUERY}.output"
		e_time="ERROR"
 	else
    	# Get end time
    	e_time=`$GTIME`
 	fi
    
    # store times
    echo "${QUERY} ${s_time} ${e_time}" >> ${OUTPUT_DIR}/results/stream${STREAM}/timing_intervals
done
